==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance.md <==
# AmazonEc2Hpc6AInstance


```text
aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance
```

```text
include('aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance')
```



| Illustration | AmazonEc2Hpc6AInstance | AmazonEc2Hpc6AInstanceCard | AmazonEc2Hpc6AInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance.png) | ![illustration for AmazonEc2Hpc6AInstance](../../../aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance.Local.png) | ![illustration for AmazonEc2Hpc6AInstanceCard](../../../aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstanceCard.Local.png) | ![illustration for AmazonEc2Hpc6AInstanceGroup](../../../aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstanceGroup.Local.png) |




## AmazonEc2Hpc6AInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2Hpc6AInstance
include('aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance')

' renders the element
AmazonEc2Hpc6AInstance('AmazonEc2Hpc6AInstance', 'Amazon Ec2 Hpc6 A Instance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2Hpc6AInstance
include('aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance')

' renders the element
AmazonEc2Hpc6AInstance('AmazonEc2Hpc6AInstance', 'Amazon Ec2 Hpc6 A Instance', 'an optional tech label')
@enduml
```

## AmazonEc2Hpc6AInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2Hpc6AInstanceCard
include('aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance')

' renders the element
AmazonEc2Hpc6AInstanceCard('AmazonEc2Hpc6AInstanceCard', 'Amazon Ec2 Hpc6 A Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2Hpc6AInstanceCard
include('aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance')

' renders the element
AmazonEc2Hpc6AInstanceCard('AmazonEc2Hpc6AInstanceCard', 'Amazon Ec2 Hpc6 A Instance Card', 'an optional description')
@enduml
```

## AmazonEc2Hpc6AInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2Hpc6AInstanceGroup
include('aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance')

' renders the element
AmazonEc2Hpc6AInstanceGroup('AmazonEc2Hpc6AInstanceGroup', 'Amazon Ec2 Hpc6 A Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2Hpc6AInstanceGroup
include('aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance')

' renders the element
AmazonEc2Hpc6AInstanceGroup('AmazonEc2Hpc6AInstanceGroup', 'Amazon Ec2 Hpc6 A Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance.md <==
# AmazonEc2Hpc6AInstance


```text
aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance
```

```text
include('aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance')
```



| Illustration | AmazonEc2Hpc6AInstance | AmazonEc2Hpc6AInstanceCard | AmazonEc2Hpc6AInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance.png) | ![illustration for AmazonEc2Hpc6AInstance](../../../aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance.Local.png) | ![illustration for AmazonEc2Hpc6AInstanceCard](../../../aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstanceCard.Local.png) | ![illustration for AmazonEc2Hpc6AInstanceGroup](../../../aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstanceGroup.Local.png) |




## AmazonEc2Hpc6AInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2Hpc6AInstance
include('aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance')

' renders the element
AmazonEc2Hpc6AInstance('AmazonEc2Hpc6AInstance', 'Amazon Ec2 Hpc6 A Instance', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2Hpc6AInstance
include('aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance')

' renders the element
AmazonEc2Hpc6AInstance('AmazonEc2Hpc6AInstance', 'Amazon Ec2 Hpc6 A Instance', 'an optional tech label', 'an optional description')
@enduml
```

## AmazonEc2Hpc6AInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2Hpc6AInstanceCard
include('aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance')

' renders the element
AmazonEc2Hpc6AInstanceCard('AmazonEc2Hpc6AInstanceCard', 'Amazon Ec2 Hpc6 A Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2Hpc6AInstanceCard
include('aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance')

' renders the element
AmazonEc2Hpc6AInstanceCard('AmazonEc2Hpc6AInstanceCard', 'Amazon Ec2 Hpc6 A Instance Card', 'an optional description')
@enduml
```

## AmazonEc2Hpc6AInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2Hpc6AInstanceGroup
include('aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance')

' renders the element
AmazonEc2Hpc6AInstanceGroup('AmazonEc2Hpc6AInstanceGroup', 'Amazon Ec2 Hpc6 A Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2Hpc6AInstanceGroup
include('aws-q2-2022/Resource/Compute/AmazonEc2Hpc6AInstance')

' renders the element
AmazonEc2Hpc6AInstanceGroup('AmazonEc2Hpc6AInstanceGroup', 'Amazon Ec2 Hpc6 A Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
